pub async fn with_accept<F, T>(accept: impl Into<String>, fut: F) -> Twhere
F: Future<Output = T>,Expand description
Run fut with the request Accept header visible to current_accept.
pub async fn with_accept<F, T>(accept: impl Into<String>, fut: F) -> Twhere
F: Future<Output = T>,Run fut with the request Accept header visible to current_accept.